==> prime_sdk_py-0.3.1-py3-none-any.whl: prime_sdk/list_onchain_address_groups.py <==
# Copyright 2025-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
#  limitations under the License.

from dataclasses import dataclass
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from typing import Optional, List
from prime_sdk.credentials import Credentials


@dataclass
class ListOnchainAddressGroupsRequest:
    portfolio_id: str
    allowed_status_codes: List[int] = None


@dataclass
class ListOnchainAddressGroupsResponse(BaseResponse):
    request: ListOnchainAddressGroupsRequest


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)
        
    def list_onchain_address_groups(self, request: ListOnchainAddressGroupsRequest) -> ListOnchainAddressGroupsResponse:
        path = f"/portfolios/{request.portfolio_id}/onchain_address_groups"
        response = self.client.request("GET", path, allowed_status_codes=request.allowed_status_codes)
        return ListOnchainAddressGroupsResponse(response.json(), request)

==> prime_sdk_py-0.4.0-py3-none-any.whl: prime_sdk/list_onchain_address_groups.py <==
# Copyright 2025-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from typing import List, Optional
from prime_sdk.credentials import Credentials
from prime_sdk.model import AddressGroup


@dataclass
class ListOnchainAddressGroupsRequest:
    portfolio_id: str
    allowed_status_codes: Optional[List[int]] = None


@dataclass
class ListOnchainAddressGroupsResponse(BaseResponse):
    address_groups: List[AddressGroup] = None


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)
        
    def list_onchain_address_groups(self, request: ListOnchainAddressGroupsRequest) -> ListOnchainAddressGroupsResponse:
        path = f"/portfolios/{request.portfolio_id}/onchain_address_groups"
        response = self.client.request("GET", path, allowed_status_codes=request.allowed_status_codes)
        return ListOnchainAddressGroupsResponse(response.json())
